<?php
/*
Plugin Name: Utupia WP Functions
Plugin URI: http://www.utupia.com/blog/produccio-propia/utupia-wp-functions/
Description: Some functions for Wordpress. <strong>utuLatestComments:</strong> Another latest comments function, a simple and light one. It shows part of the latest comments content, and their authors linked to the original comment. Code inspired by the <a href="http://agkamai.com/">Real Fast Latest Comments</a> plugin. <strong>utuPagination:</strong> Another flickr/digg pagination function, specially similar with flickr pagination if you style like it. Code inspired by the <a href="http://www.mis-algoritmos.com/2007/03/12/wp-digg-style-pagination-plugin/">WP Digg Style Pagination</a> plugin.
Author: Utopiq (Joan Viso)
Version: 1.1
Author URI: http://www.utupia.com/
*/

function utuLatestComments($comment_limit = 5, $comment_length = 96,
							$hide_pingstrackbacks = true, $hide_authors = true)
{
	global $wpdb;
	$query = "SELECT 
		$wpdb->comments.comment_author, $wpdb->comments.comment_content, 
		$wpdb->comments.comment_post_ID, $wpdb->comments.comment_ID 
		FROM $wpdb->comments 
		WHERE $wpdb->comments.comment_approved = '1' ";

	if ($hide_pingstrackbacks)  $query .= " AND $wpdb->comments.comment_type NOT LIKE '%back%' ";
	if ($hide_authors)     $query .= " AND $wpdb->comments.user_id = 0 ";

	$query .= " ORDER BY $wpdb->comments.comment_date DESC LIMIT $comment_limit ";
	$results = $wpdb->get_results($query);

	if($results)
	{
		echo '<ul class="utuLastcomments">';
		foreach($results as $comment)
		{
			$comment_content = strip_tags($comment->comment_content);
			if (strlen($comment_content) > $comment_length)
		    	$comment_content = substr($comment_content, 0, $comment_length);
			if (strlen($comment->comment_author) == 0)
				$comment->comment_author = "anònim";
			echo '<li><a rel="nofollow" href="'.get_permalink($comment->comment_post_ID).'#comment-'.$comment->comment_ID .'">'.$comment->comment_author.'</a>: '.$comment_content .'...</li>';
		}
		echo '</ul>';
	}
}

function utuPagination($prevsimbol = '&#9669;', $nextsimbol = '&#9659;', $prevlabel = 'Prev', $nextlabel = 'Next', $adjacents=1, $showalways = true)
{
	global $request, $posts_per_page, $wpdb, $paged;

	if(is_single()||is_page()) return true;

	/* Preparing vars */
	preg_match('{FROM\s(.*)\sGROUP BY}siU', $request, $matches);
	$fromwhere = $matches[1];
	$total_posts = $wpdb->get_var("SELECT count(*) FROM $fromwhere");
	// Current page number
	if(!empty($paged)) $currentpage = $paged;
	else $currentpage = 1;
	// Post start number
	if($currentpage) $startpost = ($currentpage-1) * $posts_per_page;
	else $startpost = 0;
	// Page numbers vars
	if ($currentpage == 0) $currentpage = 1;
	$prevpage = $currentpage - 1;
	$nextpage = $currentpage + 1;
	$totalpages = ceil($total_posts/$posts_per_page);
	$totaladjacents = $adjacents * 2;
	$lastbutonepage = $totalpages - 1;
	$havepages = ($totalpages>1);

	/* Drawing links */
	if ($havepages or $showalways)
	{
		ob_start();
		// Previous
		echo "<div class='utuPagination'>";
		if($currentpage > 1) echo "<a class='prev' href='".get_pagenum_link($prevpage)."'>$prevsimbol $prevlabel</a>";
		else echo "<span class='start'>$prevsimbol $prevlabel</span>";
		// Pages
		if ($totalpages < 7+$totaladjacents)
		{
			// not enough pages to break both sides
			for ($index=1; $index<=$totalpages; $index++)
			{
				if ($index == $currentpage) echo "<span class='current'>$index</span>";
				else echo "<a href='".get_pagenum_link($index)."'>$index</a>";
			}
		}
		elseif ($totalpages > 5+$totaladjacents)
		{
			// close to the beginning, hide later pages
			if($currentpage < 1+$totaladjacents)
			{
				for ($index=1; $index<4+$totaladjacents; $index++)
				{
					if ($index == $currentpage) echo "<span class='current'>$index</span>";
					else echo "<a href='".get_pagenum_link($index)."'>$index</a>";
				}
				echo "<span class='break'>...</span>";
				echo "<a href='".get_pagenum_link($lastbutonepage)."'>$lastbutonepage</a>";
				echo "<a href='".get_pagenum_link($totalpages)."'>$totalpages</a>";
			}
			// in the middle, hide some front and some back
			elseif (($totalpages-$totaladjacents > $currentpage) && ($currentpage > $totaladjacents))
			{	
				echo "<a href='".get_pagenum_link(1)."'>1</a>";
				echo "<a href='".get_pagenum_link(2)."'>2</a>";
				echo "<span class='break'>...</span>";
				for ($index=$currentpage-$adjacents; $index<=$currentpage+$adjacents; $index++)
				{
					if ($index == $currentpage) echo "<span class='current'>$index</span>";
					else echo "<a href='".get_pagenum_link($index)."'>$index</a>";
				}
				echo "<span class='break'>...</span>";
				echo "<a href='".get_pagenum_link($lastbutonepage)."'>$lastbutonepage</a>";
				echo "<a href='".get_pagenum_link($totalpages)."'>$totalpages</a>";
			}
			// close to the end, hide early pages
			else
			{
				echo "<a href='".get_pagenum_link(1)."'>1</a>";
				echo "<a href='".get_pagenum_link(2)."'>2</a>";
				echo "<span class='break'>...</span>";
				for ($index=$totalpages-(2+$totaladjacents); $index<=$totalpages; $index++)
				{
					if ($index == $currentpage) echo "<span class='current'>$index</span>";
					else echo "<a href='".get_pagenum_link($index)."'>$index</a>";
				}
			}
		}
		// Next
		if ($currentpage<($index-1)) echo "<a class='next' href='".get_pagenum_link($nextpage)."'>$nextlabel $nextsimbol</a>";
		else echo "<span class='end'>$nextlabel $nextsimbol</span>";
		echo "</div>";
		echo ob_get_clean();
	}
}
?>
